Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 46 variants DatabaseAlreadyOpen, InvalidSavepoint, RepairAborted, PersistentSavepointModified, PersistentSavepointExists, EphemeralSavepointExists, TransactionInProgress, Corrupted(String), Internal(String), UpgradeRequired(u8), ValueTooLarge(usize), TableTypeMismatch { table: String, key: TypeName, value: TypeName, }, TableIsMultimap(String), TableIsNotMultimap(String), TypeDefinitionChanged { name: TypeName, alignment: usize, width: Option<usize>, }, TableDoesNotExist(String), TableExists(String), TableAlreadyOpen(String, &'static Location<'static>), BlobNotFound(u64), BlobChecksumMismatch { sequence: u64, expected: u128, actual: u128, }, BlobWriterActive, BlobWriterFinished, BlobRangeOutOfBounds { blob_length: u64, requested_offset: u64, requested_length: u64, }, MemoryBudgetExceeded { budget: usize, used: usize, }, HistorySnapshotNotFound(u64), InvalidPageType { page_region: u32, page_index: u32, page_order: u8, found: u8, }, InvalidChildRef { page_region: u32, page_index: u32, page_order: u8, child_index: usize, is_checksum: bool, }, InvalidEntryIndex { page_region: u32, page_index: u32, page_order: u8, entry_index: usize, }, PageCorrupted { page_region: u32, page_index: u32, page_order: u8, detail: &'static str, }, CdcCursorBehindRetention { cursor_txn_id: u64, oldest_retained_txn_id: u64, }, InvalidConfiguration { message: String, }, IndexNotTrained { index_name: String, }, DimensionMismatch { index_name: String, expected: usize, actual: usize, }, InvalidIndexConfig { detail: String, }, FormatError { detail: String, }, RecoveryRequired, OutOfSpace, LockTimeout(String), Io(BackendError), DatabaseClosed, PreviousIo, LockPoisoned(&'static Location<'static>), ReadTransactionStillInUse(Box<ReadTransaction>), GroupCommitPeerFailed, GroupCommitShutdown, CompactionCancelled,
}
Superset of all other errors that can occur. Convenience enum so that users can convert all errors into a single type

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DatabaseAlreadyOpen

The Database is already open. Cannot acquire lock.



InvalidSavepoint

This savepoint is invalid or cannot be created.

Savepoints become invalid when an older savepoint is restored after it was created, and savepoints cannot be created if the transaction is “dirty” (any tables have been opened)



RepairAborted



PersistentSavepointModified

A persistent savepoint was modified



PersistentSavepointExists

A persistent savepoint exists



EphemeralSavepointExists

An Ephemeral savepoint exists



TransactionInProgress

A transaction is still in-progress



Corrupted(String)

The Database is corrupted



Internal(String)

An internal invariant was violated, indicating a bug in the database engine. This is NOT caused by on-disk corruption – it means the code has a logic error. If you encounter this error, please file a bug report.



UpgradeRequired(u8)

The database file is in an old file format and must be manually upgraded



ValueTooLarge(usize)

The value being inserted exceeds the maximum of 3GiB



TableTypeMismatch

Table types didn’t match.

Fields

table: String
value: TypeName


TableIsMultimap(String)

The table is a multimap table



TableIsNotMultimap(String)

The table is not a multimap table



TypeDefinitionChanged

Fields

alignment: usize
width: Option<usize>


TableDoesNotExist(String)

Table name does not match any table in database



TableExists(String)

Table name already exists in the database



TableAlreadyOpen(String, &'static Location<'static>)



BlobNotFound(u64)

A blob with the given sequence ID was not found in the blob store



BlobChecksumMismatch

Blob data checksum does not match the stored checksum

Fields

sequence: u64

Blob sequence number

expected: u128

Checksum stored in metadata

actual: u128

Checksum computed from the blob data



BlobWriterActive

A streaming blob writer is already active on this transaction



BlobWriterFinished

The streaming blob writer has already been finished



BlobRangeOutOfBounds

The requested byte range exceeds the blob’s length

Fields

blob_length: u64

Total blob length in bytes

requested_offset: u64

Requested range start offset

requested_length: u64

Requested range length



MemoryBudgetExceeded

The configured memory budget has been exceeded and the operation cannot proceed

Fields

budget: usize

The configured memory budget in bytes

used: usize

Current memory usage in bytes



HistorySnapshotNotFound(u64)

The requested history snapshot was not found for the given transaction ID



InvalidPageType

A B-tree page has an unexpected type byte

Fields

page_region: u32
page_index: u32
page_order: u8
found: u8


InvalidChildRef

A child pointer or checksum on a B-tree branch page is invalid

Fields

page_region: u32
page_index: u32
page_order: u8
child_index: usize
is_checksum: bool


InvalidEntryIndex

An entry index on a B-tree page is invalid or out of range

Fields

page_region: u32
page_index: u32
page_order: u8
entry_index: usize


PageCorrupted

A B-tree page has structural corruption

Fields

page_region: u32
page_index: u32
page_order: u8
detail: &'static str


CdcCursorBehindRetention

A CDC cursor position falls behind the retention window

Fields

cursor_txn_id: u64

The cursor position (transaction ID the consumer last processed)

oldest_retained_txn_id: u64

The oldest transaction ID still in the CDC log



InvalidConfiguration

A configuration parameter is invalid (e.g. page size, region size)

Fields

message: String

Description of the invalid configuration



IndexNotTrained

The IVF-PQ index has not been trained yet

Fields

index_name: String

Name of the untrained index



DimensionMismatch

Vector dimensionality does not match the index configuration

Fields

index_name: String

Name of the index

expected: usize

Dimension the index was configured with

actual: usize

Dimension of the provided vector



InvalidIndexConfig

IVF-PQ index configuration is invalid

Fields

detail: String

Description of the invalid configuration



FormatError

On-disk format validation failed (magic number, version, layout, record structure)

Fields

detail: String

Description of the format violation



RecoveryRequired

Database requires recovery before this operation can proceed



OutOfSpace

Storage space exhausted; the allocator cannot grow further



LockTimeout(String)

Timed out waiting for a write transaction lock (no_std spin-lock).



Io(BackendError)



DatabaseClosed



PreviousIo

A previous IO error occurred. The database must be closed and re-opened



LockPoisoned(&'static Location<'static>)



ReadTransactionStillInUse(Box<ReadTransaction>)

The transaction is still referenced by a table or other object



GroupCommitPeerFailed

A group commit batch was rolled back because a peer batch failed



GroupCommitShutdown

The database group committer is shutting down



CompactionCancelled

Blob compaction was cancelled by the progress callback.